@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AnomalySeverityType,
     AnomalyStatusType,
@@ -66,6 +64,7 @@ __all__ = (
     "CloudWatchMetricsDimensionTypeDef",
     "CostEstimationResourceCollectionFilterTypeDef",
     "CostEstimationTimeRangeTypeDef",
+    "DeleteInsightRequestRequestTypeDef",
     "DescribeAccountHealthResponseTypeDef",
     "DescribeAccountOverviewRequestRequestTypeDef",
     "DescribeAccountOverviewResponseTypeDef",
@@ -382,6 +381,13 @@ CostEstimationTimeRangeTypeDef = TypedDict(
     total=False,
 )
 
+DeleteInsightRequestRequestTypeDef = TypedDict(
+    "DeleteInsightRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 DescribeAccountHealthResponseTypeDef = TypedDict(
     "DescribeAccountHealthResponseTypeDef",
     {
